@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Evoution RSS Reader Plugin
- *  Copyright (C) 2007  Lucian Langa <cooly@gnome.eu.org> 
+ *  Copyright (C) 2007-2009  Lucian Langa <cooly@gnome.eu.org> 
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,37 +18,45 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
+
 #include <string.h>
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
+#include <gtk/gtk.h>
 
-#include <rss.h>
-#include <rss-config-factory.h>
+#include "rss.h"
+#include "rss-config-factory.h"
+#include "misc.h"
+#include "dbus.h"
 
 #define DBUS_PATH "/org/gnome/evolution/mail/rss"
 #define DBUS_INTERFACE "org.gnome.evolution.mail.rss.in"
 #define DBUS_REPLY_INTERFACE "org.gnome.evolution.mail.rss.out"
 
-static DBusConnection *init_dbus (void);
+#define d(x)
 
 static DBusConnection *bus = NULL;
 static gboolean enabled = FALSE;
 
-/*static void
+extern rssfeed *rf;
+
+#if 0
+static void
 send_dbus_message (const char *name, const char *data, guint new)
 {
 	DBusMessage *message;
 	
 	/* Create a new message on the DBUS_INTERFACE */
-/*	if (!(message = dbus_message_new_signal (DBUS_PATH, DBUS_INTERFACE, name)))
+	if (!(message = dbus_message_new_signal (DBUS_PATH, DBUS_INTERFACE, name)))
 		return;
 	
 	/* Appends the data as an argument to the message */
-/*	dbus_message_append_args (message,
+	dbus_message_append_args (message,
 #if DBUS_VERSION >= 310
 				  DBUS_TYPE_STRING, &data,
 #else
@@ -57,11 +65,12 @@ send_dbus_message (const char *name, const char *data, guint new)
 				  DBUS_TYPE_INVALID);
 
 	/* Sends the message */
-//	dbus_connection_send (bus, message, NULL);
+	dbus_connection_send (bus, message, NULL);
 	
 	/* Frees the message */
-/*	dbus_message_unref (message);
-}*/
+	dbus_message_unref (message);
+}
+#endif
 
 static gboolean
 reinit_dbus (gpointer user_data)
@@ -137,7 +146,6 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
     		return DBUS_HANDLER_RESULT_HANDLED;
   	}
 	else if (dbus_message_is_signal (message, DBUS_INTERFACE, "ping")) {
-		gchar *data = g_strdup("PONG");
 		DBusMessage *reply;
 		fprintf(stderr, "!!Ping!! received from %s\n",
 				dbus_message_get_sender(message));
@@ -153,7 +161,7 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
-static DBusConnection *
+DBusConnection *
 init_dbus (void)
 {
 	static DBusConnection *bus = NULL;
