@@ -1,5 +1,5 @@
 /*  Evolution RSS Reader Plugin
- *  Copyright (C) 2007-2008 Lucian Langa <cooly@gnome.eu.org>
+ *  Copyright (C) 2007-2009 Lucian Langa <cooly@gnome.eu.org>
  *         
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,22 +18,49 @@
  * vim: tabstop=4 shiftwidth=4 noexpandtab :
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
+#include <gconf/gconf-client.h>
+#ifdef HAVE_LIBSOUP_GNOME
+#include <libsoup/soup-gnome.h>
+#include <libsoup/soup-gnome-features.h>
+#endif
+
+#if (DATASERVER_VERSION >= 2023001)
+#include <libedataserver/e-proxy.h>
+#endif
 
 #include "network.h"
+#include "network-soup.h"
 #include "rss.h"
-#include "misc.c"
+#include "misc.h"
+
 
 #define USE_PROXY FALSE
 
 #define SS_TIMEOUT 30
 
+#define d(x)
+
+#if LIBSOUP_VERSION > 2024000
+SoupCookieJar *rss_soup_jar = NULL;
+#endif
+gint proxy_type = 0;
 extern rssfeed *rf;
+extern GConfClient *rss_gconf;
+extern SoupSession *webkit_session;
+#if (DATASERVER_VERSION >= 2023001)
+EProxy *proxy;
+#endif
 
 typedef struct {
 	NetStatusCallback user_cb;
 	gpointer user_data;
 	int current, total;
+	gchar *chunk;
 } CallbackInfo;
 
 static void
@@ -82,30 +109,32 @@ got_chunk_cb(SoupMessage *msg, SoupBuffer *chunk, CallbackInfo *info) {
 #if LIBSOUP_VERSION < 2003000
 		clen = soup_message_get_header(msg->response_headers,
 				"Content-length");
+			return;
 #else
         	clen = soup_message_headers_get(msg->response_headers,
 				"Content-length");
 #endif
 		if (!clen)
-			return;
-		info->total = atoi(clen);
+			info->total = 0;
+		else
+			info->total = atoi(clen);
 	}
 #if LIBSOUP_VERSION < 2003000
 	info->current += msg->response.length;
 #else
 	info->current += chunk->length;
 #endif
+	info->chunk = (gchar *)chunk->data;
 	progress = g_new0(NetStatusProgress, 1);
 
 	progress->current = info->current;
 	progress->total = info->total;
+	progress->chunk = (gchar *)chunk->data;
+	progress->chunksize = (gint)chunk->length;
 	info->user_cb(NET_STATUS_PROGRESS, progress, info->user_data);
 	g_free(progress);
 }
 
-int net_error_quark(void);
-#define NET_ERROR net_error_quark()
-
 int net_error_quark(void)
 {
 	return 0;
@@ -159,82 +188,103 @@ unblock_free (gpointer user_data, GObject *ex_msg)
 	g_hash_table_find(rf->key_session,
 		remove_if_match,
 		user_data);
-	gboolean prune = soup_session_try_prune_connection (user_data);
-	//I really don't know if his is necesarry
-	//but I believe it won't hurt
+	//this has been moved to soup-internal
+	/*gboolean prune = soup_session_try_prune_connection (user_data);
 	if (prune)
-		g_object_unref(user_data);
+		g_object_unref(user_data);*/
+	soup_session_abort (user_data);
+}
+
+#if (DATASERVER_VERSION >= 2023001)
+EProxy *
+proxy_init(void)
+{
+	EProxy *proxy;
+	proxy = e_proxy_new ();
+        e_proxy_setup_proxy (proxy);
+	return proxy;
+}
+
+void
+proxify_webkit_session(EProxy *proxy, gchar *uri)
+{
+	SoupURI *proxy_uri = NULL;
+	gint ptype = gconf_client_get_int (rss_gconf, KEY_GCONF_EVO_PROXY_TYPE, NULL);
+
+	switch (ptype) {
+#ifndef HAVE_LIBSOUP_GNOME
+	case 0:
+#endif
+	case 2:
+		if (e_proxy_require_proxy_for_uri (proxy, uri)) {
+#if (DATASERVER_VERSION >=2026000)
+			proxy_uri = e_proxy_peek_uri_for (proxy, uri);
+			d(g_print("webkit proxified %s with %s:%d\n", uri, proxy_uri->host, proxy_uri->port));
+#else
+			g_print("WARN: e_proxy_peek_uri_for() requires evolution-data-server 2.26\n");
+			return;
+#endif
+		} else 
+			d(g_print("webkit no PROXY-%s\n", uri));
+		break;
+		g_object_set (G_OBJECT (webkit_session), SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+#ifdef HAVE_LIBSOUP_GNOME
+	case 0:
+		soup_session_add_feature_by_type (webkit_session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
+		break;
+#endif
+	}
+
 }
 
 //this will insert proxy in the session
 void
-proxify_session(SoupSession *session)
+proxify_session(EProxy *proxy, SoupSession *session, gchar *uri)
 {
-#if (EVOLUTION_VERSION < 22300)		// include devel too
-    gboolean use_proxy =
-   	gconf_client_get_bool(rss_gconf, GCONF_KEY_USE_PROXY, NULL);
-    gint port_proxy =
-        gconf_client_get_int(rss_gconf, GCONF_KEY_PORT_PROXY, NULL);
-    gchar *host_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_KEY_HOST_PROXY, NULL);
-    gboolean auth_proxy =
-        gconf_client_get_bool(rss_gconf, GCONF_KEY_AUTH_PROXY, NULL);
-    gchar *user_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_KEY_USER_PROXY, NULL);
-    gchar *pass_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_KEY_PASS_PROXY, NULL);
-#else
-    gboolean use_proxy =
-   	gconf_client_get_bool(rss_gconf, GCONF_E_USE_PROXY_KEY, NULL);
-    guint proxy_type =
-   	gconf_client_get_int(rss_gconf, GCONF_E_PROXY_TYPE_KEY, NULL);
-    if (proxy_type != 2)	//emulate the same behaviour
-	use_proxy = 0;
-    gint port_proxy =
-        gconf_client_get_int(rss_gconf, GCONF_E_HTTP_PORT_KEY, NULL);
-    gchar *host_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_E_HTTP_HOST_KEY, NULL);
-    gboolean auth_proxy =
-        gconf_client_get_bool(rss_gconf, GCONF_E_USE_AUTH_KEY, NULL);
-    gchar *user_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_E_AUTH_USER_KEY, NULL);
-    gchar *pass_proxy =
-        gconf_client_get_string(rss_gconf, GCONF_E_AUTH_PWD_KEY, NULL);
-#endif
+	SoupURI *proxy_uri = NULL;
+	gint ptype = gconf_client_get_int (rss_gconf, KEY_GCONF_EVO_PROXY_TYPE, NULL);
 
-    if (use_proxy && host_proxy && port_proxy > 0)
-    {
-        gchar *proxy_uri = 
-            g_strdup_printf("http://%s:%d/", host_proxy, port_proxy); 
-
-#if LIBSOUP_VERSION < 2003000
-        SoupUri *puri = soup_uri_new (proxy_uri);
+	switch (ptype) {
+#ifndef HAVE_LIBSOUP_GNOME
+	case 0:
+#endif
+	case 2:
+		if (e_proxy_require_proxy_for_uri (proxy, uri)) {
+#if (DATASERVER_VERSION >=2026000)
+			proxy_uri = e_proxy_peek_uri_for (proxy, uri);
 #else
-        SoupURI *puri = soup_uri_new (proxy_uri);
+			g_print("WARN: e_proxy_peek_uri_for() requires evolution-data-server 2.26\n");
+			return;
 #endif
-/*	if (auth_proxy)
-	{
-		puri->user = g_strdup(user_proxy);
-		puri->passwd = g_strdup(pass_proxy);
-	}*/
-       	g_object_set (G_OBJECT (session), SOUP_SESSION_PROXY_URI, puri, NULL);
-#if LIBSOUP_VERSION < 2003000
-        if (puri)
-            g_free(puri);
+			if (proxy_uri)
+				d(g_print("proxified %s with %s:%d\n", uri, proxy_uri->host, proxy_uri->port));
+		} else 
+			d(g_print("no PROXY-%s\n", uri));
+		g_object_set (G_OBJECT (session), SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+		break;
+
+#ifdef HAVE_LIBSOUP_GNOME
+	case 0:
+			soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
+		break;
 #endif
-        if (proxy_uri)
-            g_free(proxy_uri);
-    }
+	}
+
 }
+#endif
 
 guint
 read_up(gpointer data)
 {
 	char rfeed[512];
+	guint res = 0;
+	
+	if (NULL != g_hash_table_lookup(rf->hruser, data))
+		return 1;
+
 	gchar *tmp = gen_md5(data);
 	gchar *buf = g_strconcat(tmp, ".rec", NULL);
 	g_free(tmp);
-	guint res = 0;
 
 	gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
 	if (!g_file_test(feed_dir, G_FILE_TEST_EXISTS))
@@ -244,8 +294,7 @@ read_up(gpointer data)
 	g_free(feed_dir);
 
 	FILE *fr = fopen(feed_name, "r");
-	if (fr)
-	{
+	if (fr) {
         	fgets(rfeed, 511, fr);
         	g_hash_table_insert(rf->hruser, data, g_strstrip(g_strdup(rfeed)));
         	fgets(rfeed, 511, fr);
@@ -274,8 +323,7 @@ save_up(gpointer data)
 	g_free(feed_dir);
 
 	FILE *fr = fopen(feed_name, "w+");
-	if (fr)
-	{
+	if (fr) {
         	gchar *user = g_hash_table_lookup(rf->hruser, data);
 			fputs(user, fr);
 	        fputs("\n", fr);
@@ -324,43 +372,55 @@ authenticate (SoupSession *session,
 	gpointer data)
 #endif
 {
+	if (msg->status_code == SOUP_STATUS_PROXY_UNAUTHORIZED) {
+		g_print("proxy:%d\n", soup_auth_is_for_proxy(auth));
+	SoupURI *proxy_uri;
+	g_object_get (G_OBJECT(session),
+				"proxy-uri", &proxy_uri,
+				NULL);
+	//proxy_auth_dialog("Proxy Authentication", proxy_uri->user, proxy_uri->password);
+	//g_object_set (G_OBJECT (session), SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+	return;
+	}
+
 	gchar *user = g_hash_table_lookup(rf->hruser, data);
 	gchar *pass = g_hash_table_lookup(rf->hrpass, data);
-	if (user && pass)
-	{
+	
+	if (user && pass) {
 #if LIBSOUP_VERSION < 2003000
 		*username = g_strdup(user);
 		*password = g_strdup(pass);
 #else
 	if (!retrying)
 		soup_auth_authenticate (auth, user, pass);
-#endif
+	else {
+		if (!rf->autoupdate)
+			goto authpop;
 	}
-	else
-	{
-		if (rf->soup_auth_retry)
-		{
-		//means we're already tested once and probably
-		//won't try again
-		rf->soup_auth_retry = FALSE;
-		if (!read_up(data))
-		{
-			if (create_user_pass_dialog(data))
-				rf->soup_auth_retry = FALSE;
-			else
-				rf->soup_auth_retry = TRUE;
-		}
-#if LIBSOUP_VERSION < 2003000
-		*username = g_strdup(g_hash_table_lookup(rf->hruser, data));
-		*password = g_strdup(g_hash_table_lookup(rf->hrpass, data));
-#else
-	if (!retrying)
-		soup_auth_authenticate (auth, user, pass);
 #endif
+	} else {
+		//we test for autofetching in progresss because it seems
+		//preety annoying to pop the authentication popup in front
+		//of the user every time feeds are automatically fetched
+		if (!read_up(data) && !rf->autoupdate) {
+			//we will continue after user has made a decision on 
+			//web auth dialog
+			//Bug 522147 – need to be able to pause synchronous I/O
+authpop:		if (G_OBJECT_TYPE(session) == SOUP_TYPE_SESSION_ASYNC) {
+				soup_session_pause_message(session, msg);
+			}
+			RSS_AUTH *auth_info = g_new0(RSS_AUTH, 1);
+			auth_info->url = data;
+			auth_info->soup_auth = auth;
+			auth_info->retrying = retrying;
+			auth_info->session = session;
+			auth_info->message = msg;
+			web_auth_dialog(auth_info);
 		}
 	}
 }
 
+#if LIBSOUP_VERSION < 2003000
 static void
 reauthenticate (SoupSession *session,
         SoupMessage *msg,
@@ -370,52 +430,124 @@ reauthenticate (SoupSession *session,
         char **password,
         gpointer data)
 {
-	gchar *user, *pass;
-	if (rf->soup_auth_retry)
-	{
+	if (rf->soup_auth_retry) {
 		//means we're already tested once and probably
 		//won't try again
 		rf->soup_auth_retry = FALSE;
-		if (create_user_pass_dialog(data))
-		{
+		if (create_user_pass_dialog(data)) {
 			rf->soup_auth_retry = FALSE;
-		}
-		else
-		{
+		} else {
 			rf->soup_auth_retry = TRUE;
 		}
         	*username = g_strdup(g_hash_table_lookup(rf->hruser, data));
         	*password = g_strdup(g_hash_table_lookup(rf->hrpass, data));
 	}
 }
+#endif
 
-static int
-conn_mainloop_quit (void *data)
+guint
+net_get_status(const char *url, GError **err)
 {
-	g_print("loop quit");
-  g_main_loop_quit (data);
+#if LIBSOUP_VERSION < 2003000
+	SoupUri *suri = NULL;
+#else
+	SoupURI *suri = NULL;
+#endif
+	SoupMessage *req = NULL;
+	guint response = 0;
+	SoupSession *soup_sess = NULL;
+	GSList *headers = NULL;
+
+	if (!rf->b_session)
+		rf->b_session = soup_sess = 
+			soup_session_sync_new_with_options(SOUP_SESSION_TIMEOUT, SS_TIMEOUT, NULL);		
+	else
+		soup_sess = rf->b_session;
+
+	req = soup_message_new(SOUP_METHOD_GET, url);
+	if (!req) {
+		g_set_error(err, NET_ERROR, NET_ERROR_GENERIC,
+				soup_status_get_phrase(2));			//invalid url
+		goto out;
+	}
+	for (; headers; headers = headers->next) {
+		char *header = headers->data;
+		/* soup wants the key and value separate, so we have to munge this
+		 * a bit. */
+		char *colonpos = strchr(header, ':');
+		*colonpos = 0;
+#if LIBSOUP_VERSION < 2003000
+		soup_message_add_header(req->request_headers, header, colonpos+1);
+#else
+		soup_message_headers_append(req->request_headers, header, colonpos+1);
+#endif
+		*colonpos = ':';
+	}
+	gchar *agstr = g_strdup_printf("Evolution/%s; Evolution-RSS/%s",
+			EVOLUTION_VERSION_STRING, VERSION);
+#if LIBSOUP_VERSION < 2003000
+	soup_message_add_header (req->request_headers, "User-Agent",
+                                agstr);
+#else
+	soup_message_headers_append (req->request_headers, "User-Agent",
+                                agstr);
+#endif
+	g_free(agstr);
+
+	rf->b_session = soup_sess;
+	rf->b_msg_session = req;
+	soup_session_send_message(soup_sess, req);
+
+	if (req->status_code != SOUP_STATUS_OK) {
+		//might not be a good ideea
+		soup_session_abort(soup_sess);
+		g_object_unref(soup_sess);
+		rf->b_session = NULL;
+		g_set_error(err, NET_ERROR, NET_ERROR_GENERIC,
+				soup_status_get_phrase(req->status_code));
+		goto out;
+	}
+
+out:
+	if (suri) soup_uri_free(suri);
+	response = req->status_code;
+	if (req) g_object_unref(G_OBJECT(req));
+	
+	return response;
 }
 
-
 gboolean
-net_get_unblocking(const char *url, NetStatusCallback cb, 
-				gpointer data, gpointer cb2,
-				gpointer cbdata2,
+net_get_unblocking(gchar *url, 
+				NetStatusCallback cb, gpointer data, 
+				gpointer cb2, gpointer cbdata2,
 				guint track,
 				GError **err)
 {
 	SoupMessage *msg;
-	CallbackInfo *info;
+	CallbackInfo *info = NULL;
+
 	SoupSession *soup_sess = 
 //		soup_session_async_new_with_options(SOUP_SESSION_TIMEOUT, SS_TIMEOUT, NULL);
 		soup_session_async_new();
 			
-	proxify_session(soup_sess);
-	info = g_new0(CallbackInfo, 1);
-	info->user_cb = cb;
-	info->user_data = data;
-	info->current = 0;
-	info->total = 0;
+
+#if LIBSOUP_VERSION > 2024000
+	if (rss_soup_jar) {
+		soup_session_add_feature(soup_sess, SOUP_SESSION_FEATURE(rss_soup_jar));
+	}
+#endif
+
+#if (DATASERVER_VERSION >= 2023001)
+	proxify_session(proxy, soup_sess, url);
+#endif
+	if (cb && data) {
+		info = g_new0(CallbackInfo, 1);
+		info->user_cb = cb;
+		info->user_data = data;
+		info->current = 0;
+		info->total = 0;
+	}
+
 	if (!rf->session)
 		rf->session = g_hash_table_new(g_direct_hash, g_direct_equal);
 	if (!rf->abort_session)
@@ -423,6 +555,7 @@ net_get_unblocking(const char *url, NetStatusCallback cb,
 	if (!rf->key_session)
 		rf->key_session = g_hash_table_new(g_direct_hash, g_direct_equal);
 
+
 	g_signal_connect (soup_sess, "authenticate",
             G_CALLBACK (authenticate), (gpointer)url);
 #if LIBSOUP_VERSION < 2003000
@@ -432,14 +565,13 @@ net_get_unblocking(const char *url, NetStatusCallback cb,
 
 	/* Queue an async HTTP request */
 	msg = soup_message_new ("GET", url);
-	if (!msg)
-	{
+	if (!msg) {
 		g_set_error(err, NET_ERROR, NET_ERROR_GENERIC,
 				soup_status_get_phrase(2));			//invalid url
-		return -1;
+		return FALSE;
 	}
-	if (track)
-	{
+
+	if (track) {
 		//we want to be able to abort this session by calling
 		//abort_all_soup
 		g_hash_table_insert(rf->session, soup_sess, msg);
@@ -458,8 +590,10 @@ net_get_unblocking(const char *url, NetStatusCallback cb,
 #endif
 	g_free(agstr);
 
-	g_signal_connect(G_OBJECT(msg), "got_chunk",
+	if (info) {
+		g_signal_connect(G_OBJECT(msg), "got_chunk",
 			G_CALLBACK(got_chunk_cb), info);	//FIXME Find a way to free this maybe weak_ref
+	}
 
 	soup_session_queue_message (soup_sess, msg,
            cb2, cbdata2);
@@ -469,11 +603,11 @@ net_get_unblocking(const char *url, NetStatusCallback cb,
 //	g_object_weak_ref (G_OBJECT(soup_sess), unblock_free, soup_sess);
 //	GMainLoop *mainloop = g_main_loop_new (g_main_context_default (), FALSE);
   //	g_timeout_add (10 * 1000, &conn_mainloop_quit, mainloop);
-	return 1;
+	return TRUE;
 }
 
 GString*
-net_post_blocking(const char *url, GSList *headers, GString *post,
+net_post_blocking(gchar *url, GSList *headers, GString *post,
                   NetStatusCallback cb, gpointer data,
                   GError **err) {
 #if LIBSOUP_VERSION < 2003000
@@ -492,16 +626,16 @@ net_post_blocking(const char *url, GSList *headers, GString *post,
 	else
 		soup_sess = rf->b_session;
 
+
 	g_signal_connect (soup_sess, "authenticate",
-            G_CALLBACK (authenticate), soup_sess);
+            G_CALLBACK (authenticate), (gpointer)url);
 #if LIBSOUP_VERSION < 2003000
 	g_signal_connect (soup_sess, "reauthenticate",
-            G_CALLBACK (reauthenticate), soup_sess);
+            G_CALLBACK (reauthenticate), (gpointer)url);
 #endif
 
 	req = soup_message_new(SOUP_METHOD_GET, url);
-	if (!req)
-	{
+	if (!req) {
 		g_set_error(err, NET_ERROR, NET_ERROR_GENERIC,
 				soup_status_get_phrase(2));			//invalid url
 		goto out;
@@ -533,7 +667,9 @@ net_post_blocking(const char *url, GSList *headers, GString *post,
 #endif
 	g_free(agstr);
 
-	proxify_session(soup_sess);
+#if (DATASERVER_VERSION >= 2023001)
+	proxify_session(proxy, soup_sess, url);
+#endif
 	rf->b_session = soup_sess;
 	rf->b_msg_session = req;
 	soup_session_send_message(soup_sess, req);
@@ -561,3 +697,89 @@ out:
 	return response;
 }
 
+gboolean
+cancel_soup_sess(gpointer key, gpointer value, gpointer user_data)
+{
+        if (SOUP_IS_SESSION(key)) {
+                soup_session_abort(key);
+                g_hash_table_find(rf->key_session,
+                        remove_if_match,
+                        user_data);
+        }
+        return TRUE;
+}
+
+void
+remove_weak(gpointer key, gpointer value, gpointer user_data)
+{
+        g_object_weak_unref(value, unblock_free, key);
+}
+
+void
+abort_all_soup(void)
+{
+        //abort all session
+        rf->cancel = 1;
+        rf->cancel_all = 1;
+        if (rf->abort_session) {
+                g_hash_table_foreach(rf->abort_session, remove_weak, NULL);
+                g_hash_table_foreach_remove(rf->abort_session, cancel_soup_sess, NULL);
+//              g_hash_table_foreach(rf->abort_session, cancel_soup_sess, NULL);
+                g_hash_table_destroy(rf->session);
+                rf->session = g_hash_table_new(g_direct_hash, g_direct_equal);
+        }
+        if (rf->progress_bar) {
+                gtk_progress_bar_set_fraction((GtkProgressBar *)rf->progress_bar, 1);
+                rf->progress_bar = NULL;        //there's no need to update bar once we canceled feeds
+        }
+        if (rf->b_session) {
+                soup_session_abort(rf->b_session);
+                rf->b_session = NULL;
+                rf->b_msg_session = NULL;
+        }
+	rf->cancel = 0;
+        rf->cancel_all = 0;
+}
+
+void
+sync_gecko_cookies(void)
+{
+	//this currently sux as firefox 3.5b will open
+	//cookie database file exclusively, that means import will fail
+	//even fetch will fail - we should copy this file separately for
+	//gecko renderer
+	//symlink(cookie_path, moz_cookie_path);
+	GFile *cookie_file, *moz_cookie_file;
+	gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
+	gchar *cookie_path = g_build_path("/", feed_dir, "rss-cookies.sqlite", NULL);
+	gchar *moz_cookie_path = g_build_path("/", feed_dir, "mozembed-rss", "cookies.sqlite", NULL);
+
+	cookie_file = g_file_new_for_path (cookie_path);
+	moz_cookie_file = g_file_new_for_path (moz_cookie_path);
+	g_file_copy(cookie_file, moz_cookie_file, 
+			G_FILE_COPY_OVERWRITE,
+			NULL, NULL, NULL, NULL);
+	g_free(cookie_path);
+	g_free(moz_cookie_path);
+}
+
+void
+rss_soup_init(void)
+{
+#if LIBSOUP_VERSION > 2026002 && defined(HAVE_LIBSOUP_GNOME) 
+	if (gconf_client_get_bool (rss_gconf, GCONF_KEY_ACCEPT_COOKIES, NULL)) {
+		gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
+		gchar *cookie_path = g_build_path("/", feed_dir, "rss-cookies.sqlite", NULL);
+		gchar *moz_cookie_path = g_build_path("/", feed_dir, "mozembed-rss", "cookies.sqlite", NULL);
+
+		rss_soup_jar = 
+			soup_cookie_jar_sqlite_new (cookie_path, FALSE);
+
+		if (!g_file_test(moz_cookie_path, G_FILE_TEST_EXISTS|G_FILE_TEST_IS_SYMLINK)) {
+			sync_gecko_cookies();
+		}
+		g_free(cookie_path);
+		g_free(moz_cookie_path);
+	}
+#endif
+}
