@@ -19,13 +19,23 @@
 #ifndef __PARSER_H__
 #define __PARSER_H__
 
-gchar *update_channel(const char *chn_name, char *url, char *main_date, GArray *item, GtkWidget *progress);
-
-static char *layer_find (xmlNodePtr node, char *match, char *fail);
-static char *layer_find_innerelement (xmlNodePtr node, char *match, char *el, char *fail);
-static gchar *layer_find_innerhtml (xmlNodePtr node, char *match, char *submatch, char *fail);
+gchar *update_channel(RDF *r);
+xmlDoc *rss_html_url_decode(const char *html, int len);
+char *layer_find (xmlNodePtr node, char *match, char *fail);
+char *layer_find_innerelement (xmlNodePtr node, char *match, char *el, char *fail);
+gchar *layer_find_innerhtml (xmlNodePtr node, char *match, char *submatch, char *fail);
 xmlNodePtr layer_find_pos (xmlNodePtr node, char *match, char *submatch);
-static char *layer_find_tag (xmlNodePtr node, char *match, char *fail);
+char *layer_find_tag (xmlNodePtr node, char *match, char *fail);
+char * layer_find_url (xmlNodePtr node, char *match, char *fail);
+char *layer_find_tag_prop (xmlNodePtr node, char *match, char *search, char *fail);
+gchar *encode_html_entities(gchar *source);
+gchar *decode_entities(gchar *source);
+GList *layer_find_all (xmlNodePtr node, char *match, char *fail);
+xmlDoc *parse_html(char *url, const char *html, int len);
+xmlDoc *parse_html_sux (const char *buf, guint len);
+xmlDoc *xml_parse_sux (const char *buf, int len);
+create_feed *parse_channel_line(xmlNode *top, gchar *feed_name, char *main_date);
+gchar *tree_walk (xmlNodePtr root, RDF *r);
 
 #endif /*__RSS_H__*/
 
