@@ -1,5 +1,5 @@
 /*  Evoution RSS Reader Plugin
- *  Copyright (C) 2007  Lucian Langa <cooly@gnome.eu.org> 
+ *  Copyright (C) 2007-2009  Lucian Langa <cooly@gnome.eu.org> 
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #if HAVE_DBUS
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -25,20 +29,31 @@
 #ifndef __RSS_H_
 #define __RSS_H_
 
+#include <gtk/gtk.h>
+#include <libsoup/soup.h>
+#include <mail/mail-component.h>
+
+#include <glade/glade.h>
+#include <mail/em-event.h>
+#include <camel/camel-folder.h>
+#include <camel/camel-operation.h>
+
 #define PLUGIN_INSTALL_DIR @PLUGIN_INSTALL_DIR@
-#define DEFAULT_FEEDS_FOLDER "News&Blogs"
-#define DEFAULT_NO_CHANNEL "Untitled channel"
+#define DEFAULT_FEEDS_FOLDER N_("News and Blogs")
+#define OLD_FEEDS_FOLDER "News&Blogs"
+#define DEFAULT_NO_CHANNEL N_("Untitled channel")
 #define DEFAULT_TTL 1800
+#define FEED_IMAGE_TTL 604800 /*ohne week*/
 
 /* ms between status updates to the gui */
+#ifndef _WIN32
 #define STATUS_TIMEOUT (250)
+#endif
 
+#define NETWORK_MIN_TIMEOUT (60)
 #define NETWORK_TIMEOUT (180000)
 #define HTTP_CACHE_PATH "http"
 
-GConfClient *rss_gconf;
-GSList *rss_list = NULL;
-
 typedef struct _RDF {
         char 		*uri;
         char 		*html;
@@ -48,11 +63,19 @@ typedef struct _RDF {
         guint 		type_id; 	//num type
 	gchar		*version;	//feed version
         gchar		*feedid;  	//md5 string id of feed
+	gchar		*title;		//title of the feed
+	gchar		*prefix;	//directory path
+	gchar		*maindate;	//channel date
+	GArray		*item;		//feed content
+	gchar		*image;		//feed image
 	GtkWidget	*progress;
 	guint		total;		//total articles
 	guint		ttl;		//feed specified refresh interval
         /* Soup stuff */
         SoupMessage *message;
+	guint		error;		//invalid feed
+	char		*strerror;	//error msg
+	GArray		*uids;
 } RDF;
 
 //we keep these values of a feed to be deleted in order
@@ -71,6 +94,7 @@ typedef struct _hrfeed {
 	guint hrdel_unread;
 	guint hrupdate;
 	guint hrttl;
+	guint hrttl_multiply;
 } hrfeed;
 
 typedef struct _rssfeed {
@@ -83,13 +107,14 @@ typedef struct _rssfeed {
         GHashTable      *hrt;   		//feeds name hash
         GHashTable      *hrh;   		//fetch html flag
         GHashTable      *hruser;   		//auth user hash
-        GHashTable      *hrpass;   		//auth user hash
+        GHashTable      *hrpass;   		//auth pass hash
 	gboolean	soup_auth_retry;	//wether to retry auth after an unsucessful auth
         GHashTable      *hrdel_feed;   		//option to delete messages in current feed
         GHashTable      *hrdel_days;   		//option to delete messages older then days
         GHashTable      *hrdel_messages; 	//option to keep last messages
         GHashTable      *hrdel_unread; 		//option to delete unread messages too
-        GHashTable      *hrttl;   		//feeds name hash
+        GHashTable      *hrttl;   		
+        GHashTable      *hrttl_multiply;	
         GHashTable      *hrupdate;   		//feeds update method
         GtkWidget       *feed_dialog;
         GtkWidget       *progress_dialog;
@@ -113,6 +138,7 @@ typedef struct _rssfeed {
         gboolean        setup;
         gboolean        pending;
         gboolean        import;			//import going on
+	gboolean 	autoupdate;		//feed is currently auto fetched
 	guint		feed_queue;
         gboolean        cancel; 		//cancelation signal
         gboolean        cancel_all; 		//cancelation signal
@@ -146,6 +172,7 @@ typedef struct _rssfeed {
 #define GCONF_KEY_START_CHECK "/apps/evolution/evolution-rss/startup_check"
 #define GCONF_KEY_REP_CHECK "/apps/evolution/evolution-rss/rep_check"
 #define GCONF_KEY_REP_CHECK_TIMEOUT "/apps/evolution/evolution-rss/rep_check_timeout"
+#define GCONF_KEY_SHOW_COMMENTS "/apps/evolution/evolution-rss/show_comments"
 #define GCONF_KEY_REMOVE_FOLDER "/apps/evolution/evolution-rss/remove_folder"
 #define GCONF_KEY_HTML_RENDER "/apps/evolution/evolution-rss/html_render"
 #define GCONF_KEY_HTML_JS "/apps/evolution/evolution-rss/html_js"
@@ -153,6 +180,7 @@ typedef struct _rssfeed {
 #define GCONF_KEY_STATUS_ICON "/apps/evolution/evolution-rss/status_icon"
 #define GCONF_KEY_BLINK_ICON "/apps/evolution/evolution-rss/blink_icon"
 #define GCONF_KEY_FEED_ICON "/apps/evolution/evolution-rss/feed_icon"
+#define GCONF_KEY_ACCEPT_COOKIES "/apps/evolution/evolution-rss/accept_cookies"
 
 enum {
 	RSS_FEED,
@@ -163,8 +191,11 @@ enum {
 typedef struct ADD_FEED {
 	GtkWidget	*dialog;
 	GtkWidget	*progress;
+	GtkWidget	*child;		//the dialog child
+	GladeXML	*gui;
         gchar           *feed_url;
 	gchar		*feed_name;
+	gchar 		*prefix;
         gboolean        fetch_html;	//show webpage instead of summary
         gboolean        add;		//ok button
 	gboolean	changed;
@@ -175,7 +206,10 @@ typedef struct ADD_FEED {
 	guint		del_messages;	// delete all messages but the last del_messages
 	gboolean	del_unread;	// delete unread messages too
 	guint		ttl;	// recommended update time
+	guint		ttl_multiply;	// how much we multiyply ttl value (minutes)
 	guint		update;	// feed update method global; ttl; disabled
+	gboolean	renamed;
+	gboolean	edit;
 } add_feed;
 
 typedef struct USERPASS {
@@ -183,26 +217,6 @@ typedef struct USERPASS {
 	gchar *password;
 } userpass;
 
-typedef struct _setupfeed {
-	GladeXML  *gui;
-	GtkWidget *treeview;
-	GtkWidget *add_feed;
-	GtkWidget *check1;
-	GtkWidget *check2;
-	GtkWidget *check3;
-	GtkWidget *spin;
-	GtkWidget *use_proxy;
-	GtkWidget *host_proxy;
-	GtkWidget *port_proxy;
-	GtkWidget *proxy_details;
-	GtkWidget *details;
-	GtkWidget *import;
-	GtkWidget *import_fs;
-	GtkWidget *export_fs;
-	GtkWidget *export;
-	GtkWidget *combo_hbox;
-} setupfeed;
-
 struct _send_data {
         GList *infos;
 
@@ -264,50 +278,72 @@ typedef struct CREATE_FEED {	/* used by create_mail function when called by unbl
 	gchar	*feed_fname;	// feed name file
 	gchar	*feed_uri;
 	gchar *encl;
+	gchar *comments;
+	GList *category;	// list of categories article is posted under
 } create_feed;
 
-guint           upgrade = 0;                // set to 2 when initailization successfull
-guint count = 0;
-gchar *buffer = NULL;
+typedef struct rss_auth {
+	gchar *url;
+	gchar *user;
+	gchar *pass;
+	SoupAuth *soup_auth;
+	SoupSession *session;
+	SoupMessage *message;
+	gboolean retrying;
+	GtkWidget *username;
+	GtkWidget *password;
+	GtkWidget *rememberpass;
+} RSS_AUTH;
+
+struct _rfMessage {
+        guint    status_code;
+        gchar   *body;
+        goffset  length;
+};
+
+typedef struct _rfMessage rfMessage;
 guint ftotal;
 guint farticle;
 
-u_int32_t gen_crc(const char *msg);
-gboolean create_user_pass_dialog(gchar *url);
-static void start_check_cb (GtkWidget *widget, gpointer data);
-static void err_destroy (GtkWidget *widget, guint response, gpointer data);
-static gboolean check_if_match (gpointer key, gpointer value, gpointer user_data);
+GtkDialog* create_user_pass_dialog(RSS_AUTH *auth);
+void err_destroy (GtkWidget *widget, guint response, gpointer data);
 void save_gconf_feed(void);
 void rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg);
 void rss_select_folder(gchar *folder_name);
-gpointer lookup_chn_name_by_url(gchar *url);
+gchar *lookup_chn_name_by_url(gchar *url);
 gboolean update_articles(gboolean disabler);
-static xmlNode *html_find (xmlNode *node, char *match);
+xmlNode *html_find (xmlNode *node, char *match);
 gchar *lookup_main_folder(void);
 gchar *lookup_feed_folder(gchar *folder);
+gchar *lookup_original_folder(gchar *folder);
 gchar *decode_utf8_entities(gchar *str);
 gchar *decode_html_entities(gchar *str);
 gchar *get_real_channel_name(gchar *uri, gchar *failed);
-gchar *fetch_image(gchar *url);
+gchar *fetch_image(gchar *url, gchar *link);
 void create_mail(create_feed *CF);
 void migrate_crc_md5(const char *name, gchar *url);
-void write_feed_status_line(gchar *file, gchar *needle);
 void free_cf(create_feed *CF);
 gchar *generate_safe_chn_name(gchar *chn_name);
 void update_sr_message(void);
-void update_feed_image(gchar *image, gchar *key);
-static void update_status_icon(const char *channel, gchar *title);
-static void
+void update_feed_image(RDF *r);
+void update_status_icon(const char *channel, gchar *title);
+void
+#if LIBSOUP_VERSION < 2003000
+finish_website (SoupMessage *msg, gpointer user_data);
+#else
+finish_website (SoupSession *soup_sess, SoupMessage *msg, gpointer user_data);
+#endif
+void
 #if LIBSOUP_VERSION < 2003000
 finish_enclosure (SoupMessage *msg, create_feed *user_data);
 #else
 finish_enclosure (SoupSession *soup_sess, SoupMessage *msg, create_feed *user_data);
 #endif
-static void textcb(NetStatusType status, gpointer statusdata, gpointer data);
+void generic_finish_feed(rfMessage *msg, gpointer user_data);
+void textcb(NetStatusType status, gpointer statusdata, gpointer data);
 #ifdef HAVE_GECKO
 void rss_mozilla_init(void);
 #endif
-gpointer lookup_key(gpointer key);
 void taskbar_op_set_progress(gpointer key, gchar *msg, gdouble progress);
 void taskbar_op_finish(gpointer key);
 void taskbar_push_message(gchar *message);
@@ -315,12 +351,26 @@ void taskbar_pop_message(void);
 void write_feeds_folder_line(gpointer key, gpointer value, FILE *file);
 void populate_reversed(gpointer key, gpointer value, GHashTable *hash);
 gchar *rss_component_peek_base_directory(MailComponent *component);
-static void custom_feed_timeout(void);
+void custom_feed_timeout(void);
+CamelFolder *check_feed_folder(gchar *folder_name);
+gboolean setup_feed(add_feed *feed);
+void web_auth_dialog(RSS_AUTH *auth_info);
+gchar *get_main_folder(void);
+gpointer lookup_key(gpointer key);
+void rss_delete_feed(gchar *name, gboolean folder);
+gint update_feed_folder(gchar *old_name, gchar *new_name, gboolean valid_folder);
 
+#ifdef _WIN32
+char *strcasestr(const char *a, const char *b);
 
-typedef struct FEED_FOLDERS {
-	gchar *oname;		//original folder name
-	gchar *rname;		// renamed folder name
-} feed_folders;
+const char *_e_get_gladedir (void) G_GNUC_CONST;
+const char *_e_get_imagesdir (void) G_GNUC_CONST;
+
+#undef EVOLUTION_GLADEDIR
+#define EVOLUTION_GLADEDIR _e_get_gladedir ()
+
+#undef EVOLUTION_ICONDIR
+#define EVOLUTION_ICONDIR _e_get_imagesdir ()
 
 #endif
+#endif
